==> vn-native-2-cmd-1.0.95.tgz: package/cmd/start_server.js <==
#!/usr/bin/env node
let fs = require('fs');
var cli = require('cli');
var cmd = require('node-cmd');
options = cli.parse();
try {
    if (fs.existsSync('config.xml')) {

        if (options.start && options.start === 'server') {
            cli.ok("Working ....");
            cmd.get('cordova serve',
                (err, data, stderr) => {
                    if (err) {
                        cli.error('Watch server error : Please add browser platform');
                    } else {
                        /**
                         * App run 
                         */
                        //cli.ok("Server Runing ....");
                    }
                });
            cmd.get('npm run start:dev',
                (err, data, stderr) => {
                    if (err) {
                        cli.error('Can not start dev server ');
                    } else {
                        /**
                         * App run 
                         */
                        cli.ok("Server Runing ....");
                    }
                });
        }
        if (options.start && options.start === 'ios') {
            switch(options.start) {
                case "ios" :
                    runPlatform(options.start);
                break;
                case "android" :
                    runPlatform(options.start);
                break;
                case "browser" :
                    runPlatform(options.start);
                break;
                case "osx" :
                    runPlatform(options.start);
                break;
                case "window" :
                    runPlatform(options.start);
                break;
            }
            
        }
    } else {
        throw "You need create vn native project";
    }
} catch (e) {
    console.log(e);
}   

function runPlatform(start){
    cli.ok("Working ....");
                    cmd.get('cordova run ' + start, (err, data, stderr) => {
                        if (err) {
                            cli.error('Error : do you sure this platform ? ');
                        } else {
                            /**
                             * App run 
                             */
                            cli.ok("Run platform successfully ....");
                        }
                    });
}

==> vn-native-2-cmd-1.0.96.tgz: package/cmd/start_server.js <==
#!/usr/bin/env node
let fs = require('fs');
var cli = require('cli');
var cmd = require('node-cmd');
options = cli.parse();
try {
    if (fs.existsSync('config.xml')) {

        if (options.start && options.start === 'server') {
            cli.ok("Working ....");
            cmd.get('cordova serve',
                (err, data, stderr) => {
                    if (err) {
                        cli.error('Metro server error : Please add browser platform');
                    } else {
                        /**
                         * App run 
                         */
                        //cli.ok("Server Runing ....");
                    }
                });
            cmd.get('npm run start:dev',
                (err, data, stderr) => {
                    if (err) {
                        cli.error('Can not start dev server ');
                    } else {
                        /**
                         * App run 
                         */
                        cli.ok("Server Runing ....");
                    }
                });
        }
        if (options.start && options.start === 'ios') {
            switch(options.start) {
                case "ios" :
                    runPlatform(options.start);
                break;
                case "android" :
                    runPlatform(options.start);
                break;
                case "browser" :
                    runPlatform(options.start);
                break;
                case "osx" :
                    runPlatform(options.start);
                break;
                case "window" :
                    runPlatform(options.start);
                break;
            }
            
        }
    } else {
        throw "You need create vn native project";
    }
} catch (e) {
    console.log(e);
}   

function runPlatform(start){
    cli.ok("Working ....");
                    cmd.get('cordova run ' + start, (err, data, stderr) => {
                        if (err) {
                            cli.error('Error : do you sure this platform ? ');
                        } else {
                            /**
                             * App run 
                             */
                            cli.ok("Run platform successfully ....");
                        }
                    });
}
